﻿using System;
using System.Collections.Generic;
using System.Web.Script.Serialization;
using System.Web.UI;
using System.Linq;
using System.Xml.Linq;

namespace JsTreeSample {
    public partial class _Default : Page {
        protected void Page_Load(object sender, EventArgs e) {
            _submit.Click += HandleSubmitClick;
        }

        private void HandleSubmitClick(object sender, EventArgs e) {
            string xmlString = Uri.UnescapeDataString(treeXml.Value);

            XDocument xml = XDocument.Parse(xmlString);

            // Get all the items.
            var items = from x in xml.Descendants()
                        where x.Name == "item"
                        select x;

            List<Person> people = new List<Person>();

            JavaScriptSerializer serializer = new JavaScriptSerializer();

            // Resolve the paths and Person instances.
            foreach(var item in items) {
                string[] parts = item.AncestorsAndSelf()
                    .Select(a => a.Descendants("name").First().Value)
                    .Reverse().Skip(1).ToArray();

                string path = string.Join("/", parts);

                if(item.Attribute("md") == null) {
                    continue; // Next iteration.
                }

                string serializedPerson = 
                    Uri.UnescapeDataString(item.Attribute("md").Value);

                Person p = serializer.Deserialize<Person>(serializedPerson);
                p.OrgPath = path;

                people.Add(p);
            }

            _people.DataSource = people;
            _people.DataBind();
        }
    }
}